@@ -1,24 +1,24 @@
 #' Automatic dataSet aggregation by key
 #'
-#' Automatic aggregation of a dataSet set according to a \code{key}\cr
-#' @param dataSet Matrix, data.frame or data.table (with only numeric, integer, factor, logical, character columns).
-#' @param key The name of a column of dataSet according to which the set should be aggregated (character)
+#' Automatic aggregation of a dataSet set according to a \code{key}.
+#' @param dataSet Matrix, data.frame or data.table (with only numeric, integer, factor, logical, character columns)
+#' @param key Name of a column of dataSet according to which the set should be aggregated (character)
 #' @param verbose Should the algorithm talk? (logical, default to TRUE)
-#' @param thresh number of max values for frequencies count (numerical, default to 53)
-#' @param ... optional argument: \code{functions}:  aggregation functions for numeric columns (list of functions)
+#' @param thresh Number of max values for frequencies count (numerical, default to 53)
+#' @param ... Optional argument: \code{functions}:  aggregation functions for numeric columns 
 #' (vector of function, optional, if not set we use: c(mean, min, max, sd))
 #' @details
-#' Perform aggregation depending on column type:\cr
+#' Perform aggregation depending on column type:
 #' \itemize{
-#' \item If column is numeric \code{functions} are performed on the column. So 1 numeric column 
-#' give length(functions) new columns
-#' \item If column is character or factor and have less than \code{thresh} different values, 
-#' frequency count of values is performed
-#' \item If column is character or factor with more than \code{thresh} different values, number 
-#' of different values for each \code{key} is performed
-#' \item If column is logical, count of number and rate of positive is performed.
+#'   \item If column is numeric \code{functions} are performed on the column. So 1 numeric column 
+#'     give length(functions) new columns,
+#'   \item If column is character or factor and have less than \code{thresh} different values, 
+#'     frequency count of values is performed,
+#'   \item If column is character or factor with more than \code{thresh} different values, number 
+#'     of different values for each \code{key} is performed,
+#'   \item If column is logical, count of number and rate of positive is performed.
 #' }
-#' Be careful using functions argument, the function given should be an aggregation function, 
+#' Be careful using functions argument, given functions should be an aggregation function, 
 #' meaning that for multiple values it should only return one value.
 #' @return A \code{\link{data.table}} with one line per \code{key} elements and multiple  new columns.
 #' @examples
@@ -55,6 +55,7 @@ aggregateByKey <- function(dataSet, key, verbose = TRUE, thresh = 53, ...){
   
   ## Initialization
   # Make an nice list of functions
+  functions <- c(mean = mean, min = min, max = max, sd = sd)
   if (! is.null(args[["functions"]])){
     functions <- args[["functions"]]
     # Make as vector
@@ -84,9 +85,6 @@ aggregateByKey <- function(dataSet, key, verbose = TRUE, thresh = 53, ...){
     
     functions <- true.aggFunction(functions, function_name)
   }
-  else{
-    functions <- c(mean = mean, min = min, max = max, sd = sd)
-  }
   name_separator <- build_name_separator(args)
   
   
@@ -112,7 +110,6 @@ aggregateByKey <- function(dataSet, key, verbose = TRUE, thresh = 53, ...){
       }
     }
     if (verbose){
-      close(pb); rm(pb); gc(verbose = FALSE)
       printl(function_name, ": ", ncol(result), " columns have been constructed. It took ", 
              round((proc.time() - start_time)[[3]], 2), " seconds. ")
     }
@@ -201,7 +198,7 @@ aggregateAcolumn <- function(dataSet, col, key, uniqueN_byCol, name_separator =
   }
   if (maxNbValuePerKey == 1){
     # Only one different value by key: we put the value one time by key.
-	result_tmp <- dataSet[, c(key, col), with = FALSE] # drop potentially unwanted columns
+    result_tmp <- dataSet[, c(key, col), with = FALSE] # drop potentially unwanted columns
     result_tmp <- result_tmp[!duplicated(result_tmp), ]
   }
   
