@@ -5,14 +5,14 @@
 #'
 #' Delete columns that are constant or in double in your dataSet set.
 #' @param dataSet Matrix, data.frame or data.table
-#' @param keep_cols list of columns not to drop (list of character, default to NULL)
+#' @param keep_cols List of columns not to drop (list of character, default to NULL)
 #' @param verbose Should the algorithm talk (logical or 1 or 2, default to TRUE)
 #' @param ... optional parameters to be passed to the function when called from another function
 #' @details 
 #' \code{verbose} can be set to 2 have full details from which functions, otherwise they 
-#' don't log. (\code{verbose = 1} is equivalent to \code{verbose = TRUE})
+#' don't log. (\code{verbose = 1} is equivalent to \code{verbose = TRUE}).
 #' @return 
-#' The same dataSet set but with fewer columns. Columns that are constant, in double, 
+#' The same dataSet but with fewer columns. Columns that are constant, in double, 
 #' or bijection of another have been deleted.
 #' @examples
 #' # First let's build a data.frame with 3 columns: a constant column, and a column in double
@@ -34,74 +34,72 @@ fastFilterVariables <- function(dataSet, keep_cols = NULL, verbose = TRUE, ...){
   ## Sanity check
   dataSet <- checkAndReturnDataTable(dataSet = dataSet, name = "DEBUG: see fastFilterVariables")
   is.verbose_levels(verbose, max_level = 2, function_name = function_name)
-  keep_cols <- real_cols(keep_cols, names(dataSet), function_name = function_name)
+  keep_cols <- real_cols(dataSet, keep_cols, function_name = function_name)
+  
   ## Initalization
   # Arguments for log
   args <- list(...)
   dataName <- "dataSet"
   if (length(args) > 0){
-    if (!is.null(args[["function_name"]])){
-      function_name <- args[["function_name"]]
-    }
     if (!is.null(args[["dataName"]])){
       dataName <- args[["dataName"]]
     }
   }
   
-  
   ## Computation
   # Delete constant columns
   if (verbose){
     printl(function_name, ": I check for constant columns.")
   }
-  listOfConstantCols <- whichAreConstant(dataSet, keep_cols = keep_cols, verbose = verbose >= 2)
-  if (length(listOfConstantCols) > 0){
+  constant_cols <- whichAreConstant(dataSet, keep_cols = keep_cols, verbose = verbose >= 2)
+  if (length(constant_cols) > 0){
     if (verbose){
-      printl(function_name, ": I delete ", length(listOfConstantCols), " constant column(s) in ", dataName, ".")
+      printl(function_name, ": I delete ", length(constant_cols), " constant column(s) in ", dataName, ".")
     }
-    dataSet[, (listOfConstantCols) := NULL]
+    dataSet[, (constant_cols) := NULL]
   }
   # Delete columns in double
   if (verbose){
     printl(function_name, ": I check for columns in double.")
   }
-  listOfDoubles <- whichAreInDouble(dataSet, keep_cols = keep_cols, verbose = verbose >= 2)
-  if (length(listOfDoubles) > 0){
+  double_cols <- whichAreInDouble(dataSet, keep_cols = keep_cols, verbose = verbose >= 2)
+  if (length(double_cols) > 0){
     if (verbose){
-      printl(function_name, ": I delete ", length(listOfDoubles), " column(s) that are in double in ", dataName, ".")
+      printl(function_name, ": I delete ", length(double_cols), " column(s) that are in double in ", dataName, ".")
     }  
-    dataSet[, (listOfDoubles) := NULL]
+    dataSet[, (double_cols) := NULL]
   }
   
   # Delete columns that are bijections
   if (verbose){
     printl(function_name, ": I check for columns that are bijections of another column.")
   }
-  listOfBijections <- whichAreBijection(dataSet, keep_cols = keep_cols, verbose = verbose >= 2)
-  if (length(listOfBijections) > 0){
+  bijection_cols <- whichAreBijection(dataSet, keep_cols = keep_cols, verbose = verbose >= 2)
+  if (length(bijection_cols) > 0){
     if (verbose){
-      printl(function_name, ": I delete ", length(listOfBijections), 
+      printl(function_name, ": I delete ", length(bijection_cols), 
              " column(s) that are bijections of another column in ", dataName, ".")
     }  
-    dataSet[, (listOfBijections) := NULL]
+    dataSet[, (bijection_cols) := NULL]
   }
   ## Wrapp up
   return(dataSet)
 }
 
-
 #######################################################################################
 ############################### Fast round ############################################
 #######################################################################################
 #' Fast round
 #' 
-#' Fast round of numeric in a data.table. Will only round numeric, so don't worry about characters. 
+#' Fast round of numeric columns in a data.table. Will only round numeric, so don't worry about characters. 
 #' Also, it computes it column by column so your RAM is safe too.
 #' @param dataSet matrix, data.frame or data.table
+#' @param cols List of numeric column(s) name(s) of dataSet to transform. To transform all 
+#' numerics columns, set it to "auto" (characters, default to "auto")
 #' @param digits The number of digits after comma (numeric, default to 2)
 #' @param verbose Should the algorithm talk? (logical, default to TRUE)
 #' @details
-#' It is performing round by reference on dataSet, column by column, only on numercial columns. 
+#' It is performing round by \strong{reference} on dataSet, column by column, only on numercial columns. 
 #' So that it avoid copying dataSet in RAM.
 #' @return The same datasets but as a data.table and with numeric rounded.
 #' @examples
@@ -118,7 +116,7 @@ fastFilterVariables <- function(dataSet, keep_cols = NULL, verbose = TRUE, ...){
 #' # It still work :) and you don't have to worry about the string.
 #' @import data.table
 #' @export
-fastRound <- function(dataSet, digits = 2, verbose = TRUE){
+fastRound <- function(dataSet, cols = "auto", digits = 2, verbose = TRUE){
   ## Working environement
   function_name <- "fastRound"
   
@@ -126,48 +124,43 @@ fastRound <- function(dataSet, digits = 2, verbose = TRUE){
   dataSet <- checkAndReturnDataTable(dataSet)
   if (!is.numeric(digits)){stop(paste0(function_name, ": digits should be an integer."))}
   is.verbose(verbose)
+  cols <- real_cols(dataSet, cols = cols, function_name = function_name, types = c("numeric", "integer"))
   
   ## Initialization
   digits <- round(digits, 0) # just to be safe
   
   ## Computation
   if (verbose){
-    pb <- initPB(function_name, names(dataSet))
+    pb <- initPB(function_name, cols)
   }
-  for (col in names(dataSet)){
-    if (is.numeric(dataSet[[col]])){
-      set(dataSet, NULL, col, round(dataSet[[col]], digits))
-    } 
+  for (col in cols){
+    set(dataSet, NULL, col, round(dataSet[[col]], digits))
     if (verbose){
       setPB(pb, col)
     }
   }
-  if (verbose){
-    close(pb); rm(pb)
-  }
+  gc(verbose = FALSE)
   
   ## Wrapp-up
   return(dataSet)
 }
 
-
-
 #######################################################################################
 ##################################### Handle NA #######################################
 #######################################################################################
 #' Handle NA values
 #'
-#' Function to handle NAs values depending on the class of the column
+#' Handle NAs values depending on the class of the column.
 #' @param dataSet Matrix, data.frame or data.table
 #' @param set_num NAs replacement for numeric column, (numeric or function, default to 0)
 #' @param set_logical NAs replacement for logical column, (logical or function, default to FALSE)
 #' @param set_char NAs replacement for character column, (character or function, default to "")
 #' @param verbose Should the algorithm talk (logical, default to TRUE)
 #' @details 
-#' To preserve RAM this function edits directly the dataSet set. To keep object unchanged, please use \code{\link{copy}} \cr
+#' To preserve RAM this function edits dataSet by \strong{reference}. To keep object unchanged, please use \code{\link{copy}}. \cr
 #' If you provide a function, it will be applied to the full column. So this function should handle NAs. \cr
 #' For factor columns, it will add NA to list of values.
-#' @return dataSet as a \code{\link{data.table}} with NAs handled
+#' @return dataSet as a \code{\link{data.table}} with NAs replaced.
 #' @examples
 #' # Build a useful dataSet set for example
 #' require(data.table)
@@ -232,9 +225,7 @@ fastHandleNa <- function(dataSet, set_num = 0, set_logical = FALSE,
       setPB(pb, col)
     }
   }
-  if (verbose){
-    close(pb); rm(pb)
-  }
+  gc(verbose = FALSE)
   ## Wrapp-up
   return(dataSet)
 }
@@ -244,11 +235,11 @@ fastHandleNa <- function(dataSet, set_num = 0, set_logical = FALSE,
 #######################################################################################
 #' Fast checks of equality
 #' 
-#' Performs quick check if two objects are equal 
-#' @param object1 an element, a vector, a data.frame, a data.table
-#' @param object2 an element, a vector, a data.frame, a data.table
+#' Performs quick check if two objects are equal.
+#' @param object1 An element, a vector, a data.frame, a data.table
+#' @param object2 An element, a vector, a data.frame, a data.table
 #' @details 
-#' This function is fast for very large vectors, data.frame and data.table. 
+#' This function uses exponential search trick, so it is fast for very large vectors, data.frame and data.table. 
 #' This function is also very robust; you can compare a lot of stuff without failing.
 #' @return Logical (TRUE or FALSE) if the two objects are equals.
 #' @examples
@@ -274,7 +265,7 @@ fastIsEqual <- function(object1, object2){
     return(FALSE)
   }
   # List handeling
-  if (any(class(object1) %in% c("list", "data.table", "data.frame"))){
+  if (is.data.frame(object1) || is.list(object1)){
     i <- 1
     n <- length(object1)
     result <- TRUE
@@ -286,7 +277,7 @@ fastIsEqual <- function(object1, object2){
   }
   # Simple comparaison for factors
   if (is.factor(object1)){
-    if (!(sum(levels(object1) %in% levels(object2)) == length(levels(object1)) & sum(levels(object2) %in% levels(object1)) == length(levels(object2)))){
+    if (! identical(levels(object1), levels(object2))){
       return(FALSE) # To-do Limitation: les levels vides
     }
   }
@@ -302,10 +293,11 @@ fastIsEqual <- function(object1, object2){
   }
   
   # Comparaison for long object
-  maxPower <- floor(log(length(object1)) / log(10)) + 1
+  exp_factor <- 10
+  maxPower <- floor(log(length(object1)) / log(exp_factor)) + 1
   for (i in 1:maxPower){
-    I <- (10^(i - 1)):min(10^i - 1, length(object1))
-    if (sum(object1[I] == object2[I], na.rm = TRUE) + sum(is.na(object1[I]) & is.na(object2[I])) != length(I)){
+    I <- (exp_factor^(i - 1)):min(exp_factor^i - 1, length(object1))
+    if (! identical(object1[I], object2[I])){
       return(FALSE)
     }
   }
@@ -314,14 +306,6 @@ fastIsEqual <- function(object1, object2){
   return(TRUE)
 }
 
-
-
-
-
-
-
-
-
 #######################################################################################
 ############################### Fast is bijection function ############################
 #######################################################################################
@@ -337,9 +321,10 @@ fastIsBijection <- function(object1, object2){
   
   # Comparaison for long object
   nrows <- nrow(dataSet)
-  maxPower <- floor(log(nrows)/log(10)) + 1
+  exp_factor <- 10
+  maxPower <- floor(log(nrows)/log(exp_factor)) + 1
   for (i in 1:maxPower){
-    I <- (10 ^ (i - 1)):min(10 ^ i - 1,  nrows)
+    I <- (exp_factor ^ (i - 1)):min(exp_factor ^ i - 1,  nrows)
     n1 <- uniqueN(dataSet[I, 1])
     n2 <- uniqueN(dataSet[I, 2])
     if (n1 != n2){
@@ -356,7 +341,6 @@ fastIsBijection <- function(object1, object2){
   return(TRUE)
 }
 
-
 #######################################################################################
 ############################### Fast check if has less than n elt #####################
 #######################################################################################
@@ -370,12 +354,13 @@ fastMaxNbElt <- function(object, max_n_values = 1){
   
   ## Initialization
   listOfUnique <- NULL
-  maxPower <- floor(log(length(object)) / log(10)) + 1
+  exp_factor <- 10
+  maxPower <- floor(log(length(object)) / log(exp_factor)) + 1
   i <- 1
   
   ## Computation
   for (i in 1:maxPower){
-    I <- (10 ^ (i - 1)):min(10 ^ i - 1, length(object))
+    I <- (exp_factor ^ (i - 1)):min(exp_factor ^ i - 1, length(object))
     listOfUnique <- unique( c( listOfUnique, unique( object[I])))
     if (length(listOfUnique) > max_n_values){
       return(FALSE)
