@@ -1,45 +1,42 @@
 requireNamespace("data.table")
 verbose <- TRUE
-## findAndTransformDates
-#-----------------------
-
+Sys.setlocale("LC_TIME", "C")
+## Build a testing set
+# Please make sure to send a copy of it to not transform it
 dataSet <- data.table(ID = 1:5, 
                       date1 = c("2015-01-01", "2016-01-01", "2015-09-01", "2015-03-01", "2015-01-31"), 
-                      date2 = c("2015_01_01", "2016_01_01", "2015_09_01", "2015_03_01", "2015_01_31"), 
-                      hour1 = c("23:51",     "22:08",     "10:03",     "25:33",     "1:22")
+                      date2 = as.factor(c("2015_01_01", "2016_01_01", "2015_09_01", "2015_03_01", "2015_01_31")), 
+                      date3 = c("2015_1_1", "2016_1_1", "2015_9_1", "2015_3_1", "2015_1_31"),
+                      date4 = c("01-january-2015", "01-january-2016", "01-september-2015", "01-march-2015", "31-january-2015"),
+                      hour1 = c("23:51",     "22:08",     "10:03",     "25:33",     "01:22")
 )
 
-data_transformed <- findAndTransformDates(dataSet, verbose =  verbose, n_test = 5)
+
+## findAndTransformDates
+#-----------------------
+data_transformed <- findAndTransformDates(copy(dataSet), verbose =  verbose, n_test = 5)
 
 test_that("findAndTransformDates:", 
           {
-            expect_equal(all(sapply(data_transformed, function(x)class(x)[1]) == c("integer", "POSIXct", "POSIXct", "character")), TRUE)
+            expect_true(all(sapply(data_transformed, function(x)class(x)[1]) == c("integer", "POSIXct", "POSIXct", "POSIXct", "POSIXct", "character")))
           })
 
 data(iris)
 data_transformed <- findAndTransformDates(iris, verbose =  verbose, n_test = 5)
 test_that("findAndTransformDates: no dates to find", 
           {
-            expect_equal(all(sapply(data_transformed, function(x)class(x)[1]) == c("numeric", "numeric", "numeric", "numeric", "factor")), TRUE)
+            expect_true(all(sapply(data_transformed, function(x)class(x)[1]) == c("numeric", "numeric", "numeric", "numeric", "factor")))
           })
 
 ## identifyDates
 #---------------
-dataSet <- data.table(ID = 1:5, 
-                      date1 = c("2015-01-01", "2016-01-01", "2015-09-01", "2015-03-01", "2015-01-31"), 
-                      date2 = c("2015_01_01", "2016_01_01", "2015_09_01", "2015_03_01", "2015_01_31"), 
-                      hour1 = c("23:51",     "22:08",     "10:03",     "25:33",     "1:22")
-)
-
-
-
-
-
 test_that("private function identifyDates :",
           {
-            expect_equal(length(identifyDates(dataSet, n_test = 5, verbose = verbose)), 2)
-            expect_equal(all(identifyDates(dataSet, n_test = 5, verbose = verbose)[[1]] == c( "date1", "date2")), TRUE)
-            expect_equal(all(identifyDates(dataSet, n_test = 5, verbose = verbose)[[2]] == c("%Y-%m-%d", "%Y_%m_%d")), TRUE)
+		    expect_identical(identifyDates(dataSet, n_test = 5, verbose = verbose), 
+			                 list(dates = c("date1", "date2", "date3", "date4"), 
+							      formats = c("%Y-%m-%d", "%Y_%m_%d", "%Y_%m_%d", "%d-%B-%Y")
+								  )
+							  )
           })
 
 ## identifyDatesFormats 
@@ -62,6 +59,13 @@ test_that("private function: identifyTimeStampsFormats ",
 
 
 
+## control_date_conversion
+# ------------------------
+test_that("private function: control_date_conversion ",
+          {
+            expect_true(control_date_conversion( c("2017-01-02", "01-September-2017"), c("2017-1-2", "1-september-2017")))
+            expect_true(control_date_conversion( c("2017-01-02", "01-September-2017"), c("2017-01-02", "01-september-2017")))
+          })
 
 
 
@@ -72,7 +76,7 @@ dataSet <- data.table( column1 = as.Date("2016-01-01"), column2 = as.POSIXct("20
 
 test_that("dateFormatUnifier:", 
           {
-            expect_equal(all(sapply(dateFormatUnifier(dataSet, format = "Date"), class) == c("Date", "Date")), TRUE)
+            expect_true(all(sapply(dateFormatUnifier(dataSet, format = "Date"), class) == c("Date", "Date")))
             expect_error(dateFormatUnifier(dataSet, format = "adaedeaz"), "dateFormatUnifier: only format: Date, POSXIct, POSIXlt are implemented. You gave:")
           })
 
@@ -84,8 +88,8 @@ dateAuFormatPOSIXct <- as.POSIXct("2016-01-01")
 
 test_that("is.date:", 
           {
-            expect_equal(is.date(dateAuFormatDate), TRUE)
-            expect_equal(is.date(dateAuFormatPOSIXct), TRUE)
+            expect_true(is.date(dateAuFormatDate))
+            expect_true(is.date(dateAuFormatPOSIXct))
           })
 
 
@@ -101,4 +105,5 @@ test_that("getPossibleDatesFormats:",
 
 ## formatForparse_date_time
 #--------------------------
-formatForparse_date_time()
\ No newline at end of file
+formatForparse_date_time()
+
